@@ -18,12 +18,12 @@ Puppet::Type.type(:postgresql_conf).provide(
     :to_line  => proc { |h|
 
       # simple string and numeric values don't need to be enclosed in quotes
-      if h[:value].is_a?(Fixnum)
+      if h[:value].is_a?(Numeric)
         val = h[:value].to_s
       else
         val = h[:value]
       end
-      dontneedquote = val.match(/^(\w+)$/)
+      dontneedquote = val.match(/^([\d\.]+|\w+)$/)
       dontneedequal = h[:name].match(/^(include|include_if_exists)$/i)
 
       str =  h[:name].downcase # normalize case
